@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/system.c,v 1.11 2003/08/31 11:11:00 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/system.c,v 1.12 2008/07/26 14:29:30 werner Exp $
  *
  * System Call
  *
@@ -47,6 +47,11 @@ int QuerySystemCall(char *command_line)
 extern struct itimerval value, ovalue;
 
 int SilentSystemCall(char *command_line)
+{
+  return(SilentSystemCallEx(command_line, TRUE));
+}
+
+int SilentSystemCallEx(char *command_line, BOOL enable_clock)
 {
   int result;
 #ifdef XCURSES
@@ -83,7 +88,8 @@ int SilentSystemCall(char *command_line)
   clearok( stdscr, TRUE );
 #endif /* linux */ 
 #endif /* XCURSES */
-  InitClock();
+  if(enable_clock)
+    InitClock();
   (void) GetAvailBytes( &statistic.disk_space );
   return( result ); 
 }
